@@ -12,7 +12,7 @@ implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU Library General Public License for more details.
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free Software
-Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #ifdef __GNUG__
@@ -20,7 +20,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #endif
 #include <builtin.h>
 
-_VOLATILE_VOID default_one_arg_error_handler(const char* msg)
+void default_one_arg_error_handler(const char* msg)
 {
   fputs("Error: ", stderr);
   fputs(msg, stderr);
@@ -29,7 +29,7 @@ _VOLATILE_VOID default_one_arg_error_handler(const char* msg)
 }
 
 
-_VOLATILE_VOID default_two_arg_error_handler(const char* kind, const char* msg)
+void default_two_arg_error_handler(const char* kind, const char* msg)
 {
   fputs(kind, stderr);
   fputs(" Error: ", stderr);
